@@ -2,7 +2,7 @@ package App::Donburi::Util;
 use strict;
 use warnings;
 use Exporter 'import';
-our @EXPORT = qw(conf irc xslate store send_chan send_srv);
+our @EXPORT = qw(conf irc xslate logger store send_chan send_srv);
 
 use Scope::Container;
 use Encode ();
@@ -13,6 +13,8 @@ sub irc { scope_container('irc') }
 
 sub xslate { scope_container('xslate') }
 
+sub logger { scope_container('logger') }
+
 sub store { 
     my $new_store = shift;
 
